#[repr(u8)]pub enum Status {
Show 26 variants
Success = 0,
Failure = 1,
NotAuthorized = 126,
Reserved7f = 127,
MalformedCommand = 128,
UnsupCommand = 129,
InvalidField = 133,
UnsupportedAttribute = 134,
InvalidValue = 135,
ReadOnly = 136,
InsufficientSpace = 137,
NotFound = 139,
UnreportableAttribute = 140,
InvalidDataType = 141,
InvalidSelector = 142,
Reserved92 = 146,
Timeout = 148,
Abort = 149,
InvalidImage = 150,
WaitForData = 151,
NoImageAvailable = 152,
RequireMoreImage = 153,
NotificationPending = 154,
ReservedC2 = 194,
UnsupportedCluster = 195,
Invalid(u8),
}Variants
Success = 0
Operation was successful
Failure = 1
Operation was not successful
NotAuthorized = 126
The sender of the command does not have authorization to carry out this command
Reserved7f = 127
Unknown purpose
MalformedCommand = 128
The command appears to contain the wrong fields, as detected either by the presence of one or more invalid field entries or by there being missing fields. Command not carried out. Implementer has discretion as to whether to return this error or INVALID_FIELD
UnsupCommand = 129
The specified command is not supported on the device. Command not carried out
InvalidField = 133
At least one field of the command contains an incorrect value, according to the specification the device is implemented to
UnsupportedAttribute = 134
The specified attribute does not exist on the device
InvalidValue = 135
Out of range error or set to a reserved value. Attribute keeps its old value. Note that an attribute value may be out of range if an attribute is related to another, e.g., with minimum and maximum attributes. See the individual attribute descriptions for specific details
ReadOnly = 136
Attempt to write a read-only attribute
InsufficientSpace = 137
An operation failed due to an insufficient amount of free space available
NotFound = 139
The requested information (e.g., table entry) could not be found
UnreportableAttribute = 140
Periodic reports cannot be issued for this attribute
InvalidDataType = 141
The data type given for an attribute is incorrect. Command not carried out
InvalidSelector = 142
The selector for an attribute is incorrect
Reserved92 = 146
The supplied values (e.g., contents of table cells) are inconsistent
Timeout = 148
The exchange was aborted due to excessive response time
Abort = 149
Failed case when a client or a server decides to abort the upgrade process
InvalidImage = 150
Invalid OTA upgrade image (ex. failed signature validation or signer information check or CRC check)
WaitForData = 151
Server does not have data block available yet
NoImageAvailable = 152
No OTA upgrade image available for the client
RequireMoreImage = 153
The client still requires more OTA upgrade image files to successfully upgrade
NotificationPending = 154
The command has been received and is being processed
ReservedC2 = 194
An error occurred during calibration
UnsupportedCluster = 195
The cluster is not supported
Invalid(u8)
Something else